==> tmaid-2.4.2.tar.gz: tmaid-2.4.2/src/ftype.h <==
/*
    Text maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __FORMAT_H__
#define __FORMAT_H__


#include "tmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:ファイルタイプダイアログ関数群                                           *
*                                                                             *
******************************************************************************/
/*  ja:ファイルタイプダイアログを表示する
    parent,親ウインドウ
       ind,TRUE:独立ファイルタイプあり,FALSE:なし
       RET,選択されたファイルタイプ(ftnum:独立,-1:キャンセル)               */
gint
ftype_dialog (GtkWindow *parent,
              gboolean   ind);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __FORMAT_H__ */

==> tmaid-2.4.7.tar.gz: tmaid-2.4.7/src/ftype.h <==
/*
    Text maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __FORMAT_H__
#define __FORMAT_H__


#include "tmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


/******************************************************************************
*                                                                             *
* ja:ファイルタイプダイアログ関数群                                           *
*                                                                             *
******************************************************************************/
/*  ja:ファイルタイプダイアログを表示する
    parent,親ウインドウ
       ind,TRUE:独立ファイルタイプあり,FALSE:なし
       RET,選択されたファイルタイプ(ftnum:独立,-1:キャンセル)               */
gint
ftype_dialog (GtkWindow *parent,
              gboolean   ind);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __FORMAT_H__ */
